==> image_sizes-8.x-1.13.tar.gz: image_sizes/js/image-sizes.js <==
(function ($, Drupal) {
  Drupal.behaviors.imageSizesBehavior = {
    attach: function (context, settings) {

      $('img.image-sizes', context).once('imageSizesBehaviorLoad').each(function () {
        if (!$(this).data('image-sizes')) {
          $(this).data('image-sizes', JSON.parse($(this).attr('data-src')));
        }
        this.addEventListener('load', load, false);
        $(this).on('image:size-check', function() {
          imageSizesSetUrl(this);
        });
      });

      $.map($('img.image-sizes', context),function(ele){
        var parent = $(ele).parent();
        new ResizeSensor(parent, function() {
          parent.find('> img.image-sizes').each(function(){
            if ($(this).visible(true)) {
              imageSizesSetUrl(this);
            }
          })
        });
      });

      $(window).on('scroll resize scrollstop image:screen-check', init);

      $(window).scroll();
    }
  };
  function load(e) {
    ele = e.srcElement;
    $(ele).attr('width', ele.naturalWidth).attr('height', ele.naturalHeight);
    $(ele).removeClass('pre-load');
  }
  function init() {
    $('img.image-sizes').each(function(){
      if ($(this).visible(true)) {
        imageSizesSetUrl(this);
      }
    });
  }
  function imageSizesSetUrl(ele) {
    var width = $(ele).parent().width();
    var conf = $(ele).data('image-sizes');
    var newUrl = false;
    var a;
    for ( var a in conf ) {
      newUrl = conf[a];
      if (a >= width) {
        break;
      }
    }
    if (width > a || newUrl == false) {
      ele.src = $(ele).attr('data-src-fallback');
      $(ele).trigger('image:size-checked')
      return;
    }
    if (newUrl !== ele.src) {
      ele.src = newUrl;
      $(ele).trigger('image:size-checked')
    }
  }
})(jQuery, Drupal);

==> image_sizes-8.x-1.16.tar.gz: image_sizes/js/image-sizes.js <==
(function ($, Drupal) {
  Drupal.behaviors.imageSizesBehavior = {
    attach: function (context, settings) {

      $('img.image-sizes', context).once('imageSizesBehaviorLoad').each(function () {
        if (!$(this).data('image-sizes')) {
          $(this).data('image-sizes', JSON.parse($(this).attr('data-src')));
        }
        $(this).on('image:size-check', function() {
          imageSizesSetUrl(this);
        });
      });

      $.map($('img.image-sizes', context),function(ele){
        var parent = $(ele).parent();
        new ResizeSensor(parent, function() {
          parent.find('> img.image-sizes').each(function(){
            if ($(this).visible(true)) {
              imageSizesSetUrl(this);
            }
          })
        });
      });

      $(window).on('scroll resize scrollstop image:screen-check', init);

      $(window).scroll();
    }
  };
  function init() {
    $('img.image-sizes').each(function(){
      if ($(this).visible(true)) {
        imageSizesSetUrl(this);
      }
    });
  }
  function imageSizesSetUrl(ele) {
    var width = $(ele).parent().width();
    var conf = $(ele).data('image-sizes');
    var newUrl = false;
    var a;
    for ( var a in conf ) {
      newUrl = conf[a];
      if (a >= width) {
        break;
      }
    }
    if (width > a || newUrl == false) {
      newUrl = $(ele).attr('data-src-fallback');
    }
    if (newUrl !== ele.src) {
      let img = new Image();
      $(ele).addClass('loading');
      $(img).on('load', function() {
        $(ele).removeClass('pre-load').removeClass('loading').addClass('fade-in-on-load');
        ele.src = this.src;
        delete this;
      });

      img.src = newUrl;
    }
  }
})(jQuery, Drupal);
